<?php

use YahnisElsts\PluginUpdateChecker\v5\PucFactory;

$pversion = '1.00';

//Add styles
function overtracking_enqueue_style() {
    global $pversion;
    wp_register_style('style_overtracking', FILE_OVT_URL . 'assets/style.css', false, mt_rand(0, 50000));
    wp_enqueue_style('style_overtracking');
    wp_register_script('js_overtracking', FILE_OVT_URL . 'assets/overtracking.js', array('jquery'), $pversion, true);
    wp_enqueue_script('js_overtracking');
}

add_action('admin_enqueue_scripts', 'overtracking_enqueue_style');
//Autoupdater
require FILEPATH_OVT . 'plugin-update-checker/plugin-update-checker.php';
$myUpdateChecker = PucFactory::buildUpdateChecker(
                PLUGIN_OVT_DOMAIN . '', FILEPATH_OVT . 'overtracking.php', 'overtracking'
);

function overtracking_settings() {
    global $events;
    $overtrackingconfig = get_option('overtracking_config');
    //Settings function
    $enableevents = (isset($overtrackingconfig['overtrackingcode']) && !empty($overtrackingconfig['overtrackingcode'])) ? true : false;
    if (isset($_POST['overtrackingcode']) && !empty($_POST['overtrackingcode'])) {
        //Save code
        $overtrackingcode = trim(stripcslashes($_POST['overtrackingcode']));
        $overtrackingcode = trim(str_replace(['https://cdn.overtracking.com/t/', '/', '\/', '"', 'script', 'defer', 'src', '=', '<', '>', ''], '', $overtrackingcode));
        $eventssave = (!isset($overtrackingconfig['events'])) ? [] : $overtrackingconfig['events'];
        $overtrackingconfig = ['last_update' => time(), 'overtrackingcode' => $overtrackingcode, 'events' => $eventssave];
        //Save options
        update_option('overtracking_config', $overtrackingconfig);
        if ($enableevents) {
            $msg = ['type' => 'noticeovt-success', 'text' => __('Tracking code updated successfully', 'overtracking')];
        }
        $enableevents = true;
    }

    if ($enableevents) {
        require(FILEPATH_OVT . 'views/events.php');
    } else {
        require(FILEPATH_OVT . 'views/settings.php');
    }
}

function validateformcreateovertracking() {
    global $wpdb, $events, $table_prefix;
    $requiredfields = ['event_type', 'event_key', 'event_value'];
    if (check_ajax_referer('createventovertracking') && checkwpovertracking($_POST, $requiredfields) && array_key_exists($_POST['event_type'], $events)) {
        //Add event to list
        $overtrackingconfig = get_option('overtracking_config');
        $eventtype = sanitize_text_field($_POST['event_type']);
        $key = sanitize_text_field($_POST['event_key']);
        $value = sanitize_text_field($_POST['event_value']);
        $overtrackingconfig['events'][$eventtype][] = ['key' => $key, 'value' => $value];
        $overtrackingconfig['last_update'] = time();
        //Save options
        update_option('overtracking_config', $overtrackingconfig);
        //Show message
        $valueresult = ($value == 'yes') ? __('Yes', 'overtacking') : __('No', 'overtacking');
        $buttonurl = wp_nonce_url(get_admin_url() . "admin.php?page=deleteovertrackingevent&type={$eventtype}&id={$key}", "deleteovertrackingevent{$eventtype}_{$key}");
        $result = ['result' => true, 'text' => __("Event added successfully", 'overtracking'), 'line' => "<tr><td>{$events[$eventtype]}</td><td>{$key}<td>{$valueresult}</td><td><a href=\"{$buttonurl}\" class=\"btn-danger\"> <span class=\"dashicons dashicons-trash\"></span></a></td></tr>"];
    } else {
        $result = ['result' => false, 'text' => __('All fields are required', 'overtracking')];
    }

    wp_send_json($result);
    wp_die();
}

add_action('wp_ajax_validateformcreateovertracking', 'validateformcreateovertracking');
add_action('wp_ajax_nopriv_validateformcreateovertracking', 'validateformcreateovertracking');

function validateformdeleteovertracking() {
    global $wpdb, $table_prefix;
    $requiredfields = ['type'];
    if (check_ajax_referer('deleteeventovertracking') && checkwpovertracking($_POST, $requiredfields)) {
        $typeevent = esc_sql(sanitize_text_field($_POST['type']));
        $idevent = esc_sql(intval($_POST['key']));
        $overtrackingconfig = get_option('overtracking_config');
        unset($overtrackingconfig['events'][$typeevent][$idevent]);
        $overtrackingconfig['last_update'] = time();
        //Save options
        update_option('overtracking_config', $overtrackingconfig);
        $result = ['result' => true, 'text' => __("Event deleted successfully", 'overtracking')];
    } else {
        $result = ['result' => false, 'text' => __('All fields are required', 'overtracking')];
    }

    wp_send_json($result);
    wp_die();
}

add_action('wp_ajax_validateformdeleteovertracking', 'validateformdeleteovertracking');
add_action('wp_ajax_nopriv_validateformdeleteovertracking', 'validateformdeleteovertracking');


//Check is complete form
function checkwpovertracking($data, $info) {
    $status = true;
    foreach ($info as $i) {
        if (!isset($data[$i]) OR empty($data[$i])) {
            $status = false;
        }
    }
    return $status;
}
